# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvoiceItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invoice_item_id': 'str',
        'invoice_id': 'str',
        'linked_invoice_item_id': 'str',
        'account_id': 'str',
        'child_account_id': 'str',
        'bundle_id': 'str',
        'subscription_id': 'str',
        'product_name': 'str',
        'plan_name': 'str',
        'phase_name': 'str',
        'usage_name': 'str',
        'pretty_product_name': 'str',
        'pretty_plan_name': 'str',
        'pretty_phase_name': 'str',
        'pretty_usage_name': 'str',
        'item_type': 'str',
        'description': 'str',
        'start_date': 'date',
        'end_date': 'date',
        'amount': 'float',
        'rate': 'float',
        'currency': 'str',
        'quantity': 'int',
        'item_details': 'str',
        'catalog_effective_date': 'datetime',
        'child_items': 'list[InvoiceItem]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'invoice_item_id': 'invoiceItemId',
        'invoice_id': 'invoiceId',
        'linked_invoice_item_id': 'linkedInvoiceItemId',
        'account_id': 'accountId',
        'child_account_id': 'childAccountId',
        'bundle_id': 'bundleId',
        'subscription_id': 'subscriptionId',
        'product_name': 'productName',
        'plan_name': 'planName',
        'phase_name': 'phaseName',
        'usage_name': 'usageName',
        'pretty_product_name': 'prettyProductName',
        'pretty_plan_name': 'prettyPlanName',
        'pretty_phase_name': 'prettyPhaseName',
        'pretty_usage_name': 'prettyUsageName',
        'item_type': 'itemType',
        'description': 'description',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'amount': 'amount',
        'rate': 'rate',
        'currency': 'currency',
        'quantity': 'quantity',
        'item_details': 'itemDetails',
        'catalog_effective_date': 'catalogEffectiveDate',
        'child_items': 'childItems',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, invoice_item_id=None, invoice_id=None, linked_invoice_item_id=None, account_id=None, child_account_id=None, bundle_id=None, subscription_id=None, product_name=None, plan_name=None, phase_name=None, usage_name=None, pretty_product_name=None, pretty_plan_name=None, pretty_phase_name=None, pretty_usage_name=None, item_type=None, description=None, start_date=None, end_date=None, amount=None, rate=None, currency=None, quantity=None, item_details=None, catalog_effective_date=None, child_items=None, audit_logs=None):  # noqa: E501
        """InvoiceItem - a model defined in Swagger"""  # noqa: E501
        self._invoice_item_id = None
        self._invoice_id = None
        self._linked_invoice_item_id = None
        self._account_id = None
        self._child_account_id = None
        self._bundle_id = None
        self._subscription_id = None
        self._product_name = None
        self._plan_name = None
        self._phase_name = None
        self._usage_name = None
        self._pretty_product_name = None
        self._pretty_plan_name = None
        self._pretty_phase_name = None
        self._pretty_usage_name = None
        self._item_type = None
        self._description = None
        self._start_date = None
        self._end_date = None
        self._amount = None
        self._rate = None
        self._currency = None
        self._quantity = None
        self._item_details = None
        self._catalog_effective_date = None
        self._child_items = None
        self._audit_logs = None
        self.discriminator = None
        self.invoice_item_id = invoice_item_id
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if linked_invoice_item_id is not None:
            self.linked_invoice_item_id = linked_invoice_item_id
        self.account_id = account_id
        if child_account_id is not None:
            self.child_account_id = child_account_id
        if bundle_id is not None:
            self.bundle_id = bundle_id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if product_name is not None:
            self.product_name = product_name
        if plan_name is not None:
            self.plan_name = plan_name
        if phase_name is not None:
            self.phase_name = phase_name
        if usage_name is not None:
            self.usage_name = usage_name
        if pretty_product_name is not None:
            self.pretty_product_name = pretty_product_name
        if pretty_plan_name is not None:
            self.pretty_plan_name = pretty_plan_name
        if pretty_phase_name is not None:
            self.pretty_phase_name = pretty_phase_name
        if pretty_usage_name is not None:
            self.pretty_usage_name = pretty_usage_name
        if item_type is not None:
            self.item_type = item_type
        if description is not None:
            self.description = description
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if amount is not None:
            self.amount = amount
        if rate is not None:
            self.rate = rate
        if currency is not None:
            self.currency = currency
        if quantity is not None:
            self.quantity = quantity
        if item_details is not None:
            self.item_details = item_details
        if catalog_effective_date is not None:
            self.catalog_effective_date = catalog_effective_date
        if child_items is not None:
            self.child_items = child_items
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def invoice_item_id(self):
        """Gets the invoice_item_id of this InvoiceItem.  # noqa: E501


        :return: The invoice_item_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._invoice_item_id

    @invoice_item_id.setter
    def invoice_item_id(self, invoice_item_id):
        """Sets the invoice_item_id of this InvoiceItem.


        :param invoice_item_id: The invoice_item_id of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if invoice_item_id is None:
            raise ValueError("Invalid value for `invoice_item_id`, must not be `None`")  # noqa: E501

        self._invoice_item_id = invoice_item_id

    @property
    def invoice_id(self):
        """Gets the invoice_id of this InvoiceItem.  # noqa: E501


        :return: The invoice_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this InvoiceItem.


        :param invoice_id: The invoice_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def linked_invoice_item_id(self):
        """Gets the linked_invoice_item_id of this InvoiceItem.  # noqa: E501


        :return: The linked_invoice_item_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._linked_invoice_item_id

    @linked_invoice_item_id.setter
    def linked_invoice_item_id(self, linked_invoice_item_id):
        """Sets the linked_invoice_item_id of this InvoiceItem.


        :param linked_invoice_item_id: The linked_invoice_item_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._linked_invoice_item_id = linked_invoice_item_id

    @property
    def account_id(self):
        """Gets the account_id of this InvoiceItem.  # noqa: E501


        :return: The account_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this InvoiceItem.


        :param account_id: The account_id of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if account_id is None:
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def child_account_id(self):
        """Gets the child_account_id of this InvoiceItem.  # noqa: E501


        :return: The child_account_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._child_account_id

    @child_account_id.setter
    def child_account_id(self, child_account_id):
        """Sets the child_account_id of this InvoiceItem.


        :param child_account_id: The child_account_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._child_account_id = child_account_id

    @property
    def bundle_id(self):
        """Gets the bundle_id of this InvoiceItem.  # noqa: E501


        :return: The bundle_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, bundle_id):
        """Sets the bundle_id of this InvoiceItem.


        :param bundle_id: The bundle_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._bundle_id = bundle_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this InvoiceItem.  # noqa: E501


        :return: The subscription_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this InvoiceItem.


        :param subscription_id: The subscription_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def product_name(self):
        """Gets the product_name of this InvoiceItem.  # noqa: E501


        :return: The product_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this InvoiceItem.


        :param product_name: The product_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._product_name = product_name

    @property
    def plan_name(self):
        """Gets the plan_name of this InvoiceItem.  # noqa: E501


        :return: The plan_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._plan_name

    @plan_name.setter
    def plan_name(self, plan_name):
        """Sets the plan_name of this InvoiceItem.


        :param plan_name: The plan_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._plan_name = plan_name

    @property
    def phase_name(self):
        """Gets the phase_name of this InvoiceItem.  # noqa: E501


        :return: The phase_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._phase_name

    @phase_name.setter
    def phase_name(self, phase_name):
        """Sets the phase_name of this InvoiceItem.


        :param phase_name: The phase_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._phase_name = phase_name

    @property
    def usage_name(self):
        """Gets the usage_name of this InvoiceItem.  # noqa: E501


        :return: The usage_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._usage_name

    @usage_name.setter
    def usage_name(self, usage_name):
        """Sets the usage_name of this InvoiceItem.


        :param usage_name: The usage_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._usage_name = usage_name

    @property
    def pretty_product_name(self):
        """Gets the pretty_product_name of this InvoiceItem.  # noqa: E501


        :return: The pretty_product_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._pretty_product_name

    @pretty_product_name.setter
    def pretty_product_name(self, pretty_product_name):
        """Sets the pretty_product_name of this InvoiceItem.


        :param pretty_product_name: The pretty_product_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._pretty_product_name = pretty_product_name

    @property
    def pretty_plan_name(self):
        """Gets the pretty_plan_name of this InvoiceItem.  # noqa: E501


        :return: The pretty_plan_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._pretty_plan_name

    @pretty_plan_name.setter
    def pretty_plan_name(self, pretty_plan_name):
        """Sets the pretty_plan_name of this InvoiceItem.


        :param pretty_plan_name: The pretty_plan_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._pretty_plan_name = pretty_plan_name

    @property
    def pretty_phase_name(self):
        """Gets the pretty_phase_name of this InvoiceItem.  # noqa: E501


        :return: The pretty_phase_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._pretty_phase_name

    @pretty_phase_name.setter
    def pretty_phase_name(self, pretty_phase_name):
        """Sets the pretty_phase_name of this InvoiceItem.


        :param pretty_phase_name: The pretty_phase_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._pretty_phase_name = pretty_phase_name

    @property
    def pretty_usage_name(self):
        """Gets the pretty_usage_name of this InvoiceItem.  # noqa: E501


        :return: The pretty_usage_name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._pretty_usage_name

    @pretty_usage_name.setter
    def pretty_usage_name(self, pretty_usage_name):
        """Sets the pretty_usage_name of this InvoiceItem.


        :param pretty_usage_name: The pretty_usage_name of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._pretty_usage_name = pretty_usage_name

    @property
    def item_type(self):
        """Gets the item_type of this InvoiceItem.  # noqa: E501


        :return: The item_type of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this InvoiceItem.


        :param item_type: The item_type of this InvoiceItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["EXTERNAL_CHARGE", "FIXED", "RECURRING", "REPAIR_ADJ", "CBA_ADJ", "CREDIT_ADJ", "ITEM_ADJ", "USAGE", "TAX", "PARENT_SUMMARY"]  # noqa: E501
        if item_type not in allowed_values:
            raise ValueError(
                "Invalid value for `item_type` ({0}), must be one of {1}"  # noqa: E501
                .format(item_type, allowed_values)
            )

        self._item_type = item_type

    @property
    def description(self):
        """Gets the description of this InvoiceItem.  # noqa: E501


        :return: The description of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InvoiceItem.


        :param description: The description of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def start_date(self):
        """Gets the start_date of this InvoiceItem.  # noqa: E501


        :return: The start_date of this InvoiceItem.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this InvoiceItem.


        :param start_date: The start_date of this InvoiceItem.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this InvoiceItem.  # noqa: E501


        :return: The end_date of this InvoiceItem.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this InvoiceItem.


        :param end_date: The end_date of this InvoiceItem.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def amount(self):
        """Gets the amount of this InvoiceItem.  # noqa: E501


        :return: The amount of this InvoiceItem.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceItem.


        :param amount: The amount of this InvoiceItem.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def rate(self):
        """Gets the rate of this InvoiceItem.  # noqa: E501


        :return: The rate of this InvoiceItem.  # noqa: E501
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this InvoiceItem.


        :param rate: The rate of this InvoiceItem.  # noqa: E501
        :type: float
        """

        self._rate = rate

    @property
    def currency(self):
        """Gets the currency of this InvoiceItem.  # noqa: E501


        :return: The currency of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceItem.


        :param currency: The currency of this InvoiceItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def quantity(self):
        """Gets the quantity of this InvoiceItem.  # noqa: E501


        :return: The quantity of this InvoiceItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this InvoiceItem.


        :param quantity: The quantity of this InvoiceItem.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def item_details(self):
        """Gets the item_details of this InvoiceItem.  # noqa: E501


        :return: The item_details of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._item_details

    @item_details.setter
    def item_details(self, item_details):
        """Sets the item_details of this InvoiceItem.


        :param item_details: The item_details of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._item_details = item_details

    @property
    def catalog_effective_date(self):
        """Gets the catalog_effective_date of this InvoiceItem.  # noqa: E501


        :return: The catalog_effective_date of this InvoiceItem.  # noqa: E501
        :rtype: datetime
        """
        return self._catalog_effective_date

    @catalog_effective_date.setter
    def catalog_effective_date(self, catalog_effective_date):
        """Sets the catalog_effective_date of this InvoiceItem.


        :param catalog_effective_date: The catalog_effective_date of this InvoiceItem.  # noqa: E501
        :type: datetime
        """

        self._catalog_effective_date = catalog_effective_date

    @property
    def child_items(self):
        """Gets the child_items of this InvoiceItem.  # noqa: E501


        :return: The child_items of this InvoiceItem.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._child_items

    @child_items.setter
    def child_items(self, child_items):
        """Sets the child_items of this InvoiceItem.


        :param child_items: The child_items of this InvoiceItem.  # noqa: E501
        :type: list[InvoiceItem]
        """

        self._child_items = child_items

    @property
    def audit_logs(self):
        """Gets the audit_logs of this InvoiceItem.  # noqa: E501


        :return: The audit_logs of this InvoiceItem.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this InvoiceItem.


        :param audit_logs: The audit_logs of this InvoiceItem.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoiceItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TieredBlock(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'unit': 'str',
        'size': 'str',
        'max': 'str',
        'prices': 'list[Price]'
    }

    attribute_map = {
        'unit': 'unit',
        'size': 'size',
        'max': 'max',
        'prices': 'prices'
    }

    def __init__(self, unit=None, size=None, max=None, prices=None):  # noqa: E501
        """TieredBlock - a model defined in Swagger"""  # noqa: E501
        self._unit = None
        self._size = None
        self._max = None
        self._prices = None
        self.discriminator = None
        if unit is not None:
            self.unit = unit
        if size is not None:
            self.size = size
        if max is not None:
            self.max = max
        if prices is not None:
            self.prices = prices

    @property
    def unit(self):
        """Gets the unit of this TieredBlock.  # noqa: E501


        :return: The unit of this TieredBlock.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this TieredBlock.


        :param unit: The unit of this TieredBlock.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def size(self):
        """Gets the size of this TieredBlock.  # noqa: E501


        :return: The size of this TieredBlock.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this TieredBlock.


        :param size: The size of this TieredBlock.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def max(self):
        """Gets the max of this TieredBlock.  # noqa: E501


        :return: The max of this TieredBlock.  # noqa: E501
        :rtype: str
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this TieredBlock.


        :param max: The max of this TieredBlock.  # noqa: E501
        :type: str
        """

        self._max = max

    @property
    def prices(self):
        """Gets the prices of this TieredBlock.  # noqa: E501


        :return: The prices of this TieredBlock.  # noqa: E501
        :rtype: list[Price]
        """
        return self._prices

    @prices.setter
    def prices(self, prices):
        """Sets the prices of this TieredBlock.


        :param prices: The prices of this TieredBlock.  # noqa: E501
        :type: list[Price]
        """

        self._prices = prices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TieredBlock, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TieredBlock):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'name': 'str',
        'first_name_length': 'int',
        'external_key': 'str',
        'email': 'str',
        'bill_cycle_day_local': 'int',
        'currency': 'str',
        'parent_account_id': 'str',
        'is_payment_delegated_to_parent': 'bool',
        'payment_method_id': 'str',
        'reference_time': 'datetime',
        'time_zone': 'str',
        'address1': 'str',
        'address2': 'str',
        'postal_code': 'str',
        'company': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'locale': 'str',
        'phone': 'str',
        'notes': 'str',
        'is_migrated': 'bool',
        'account_balance': 'float',
        'account_cba': 'float',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'name': 'name',
        'first_name_length': 'firstNameLength',
        'external_key': 'externalKey',
        'email': 'email',
        'bill_cycle_day_local': 'billCycleDayLocal',
        'currency': 'currency',
        'parent_account_id': 'parentAccountId',
        'is_payment_delegated_to_parent': 'isPaymentDelegatedToParent',
        'payment_method_id': 'paymentMethodId',
        'reference_time': 'referenceTime',
        'time_zone': 'timeZone',
        'address1': 'address1',
        'address2': 'address2',
        'postal_code': 'postalCode',
        'company': 'company',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'locale': 'locale',
        'phone': 'phone',
        'notes': 'notes',
        'is_migrated': 'isMigrated',
        'account_balance': 'accountBalance',
        'account_cba': 'accountCBA',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, account_id=None, name=None, first_name_length=None, external_key=None, email=None, bill_cycle_day_local=None, currency=None, parent_account_id=None, is_payment_delegated_to_parent=None, payment_method_id=None, reference_time=None, time_zone=None, address1=None, address2=None, postal_code=None, company=None, city=None, state=None, country=None, locale=None, phone=None, notes=None, is_migrated=None, account_balance=None, account_cba=None, audit_logs=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501
        self._account_id = None
        self._name = None
        self._first_name_length = None
        self._external_key = None
        self._email = None
        self._bill_cycle_day_local = None
        self._currency = None
        self._parent_account_id = None
        self._is_payment_delegated_to_parent = None
        self._payment_method_id = None
        self._reference_time = None
        self._time_zone = None
        self._address1 = None
        self._address2 = None
        self._postal_code = None
        self._company = None
        self._city = None
        self._state = None
        self._country = None
        self._locale = None
        self._phone = None
        self._notes = None
        self._is_migrated = None
        self._account_balance = None
        self._account_cba = None
        self._audit_logs = None
        self.discriminator = None
        if account_id is not None:
            self.account_id = account_id
        if name is not None:
            self.name = name
        if first_name_length is not None:
            self.first_name_length = first_name_length
        if external_key is not None:
            self.external_key = external_key
        if email is not None:
            self.email = email
        if bill_cycle_day_local is not None:
            self.bill_cycle_day_local = bill_cycle_day_local
        if currency is not None:
            self.currency = currency
        if parent_account_id is not None:
            self.parent_account_id = parent_account_id
        if is_payment_delegated_to_parent is not None:
            self.is_payment_delegated_to_parent = is_payment_delegated_to_parent
        if payment_method_id is not None:
            self.payment_method_id = payment_method_id
        if reference_time is not None:
            self.reference_time = reference_time
        if time_zone is not None:
            self.time_zone = time_zone
        if address1 is not None:
            self.address1 = address1
        if address2 is not None:
            self.address2 = address2
        if postal_code is not None:
            self.postal_code = postal_code
        if company is not None:
            self.company = company
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if locale is not None:
            self.locale = locale
        if phone is not None:
            self.phone = phone
        if notes is not None:
            self.notes = notes
        if is_migrated is not None:
            self.is_migrated = is_migrated
        if account_balance is not None:
            self.account_balance = account_balance
        if account_cba is not None:
            self.account_cba = account_cba
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501


        :return: The account_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.


        :param account_id: The account_id of this Account.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def name(self):
        """Gets the name of this Account.  # noqa: E501


        :return: The name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Account.


        :param name: The name of this Account.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def first_name_length(self):
        """Gets the first_name_length of this Account.  # noqa: E501


        :return: The first_name_length of this Account.  # noqa: E501
        :rtype: int
        """
        return self._first_name_length

    @first_name_length.setter
    def first_name_length(self, first_name_length):
        """Sets the first_name_length of this Account.


        :param first_name_length: The first_name_length of this Account.  # noqa: E501
        :type: int
        """

        self._first_name_length = first_name_length

    @property
    def external_key(self):
        """Gets the external_key of this Account.  # noqa: E501


        :return: The external_key of this Account.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Account.


        :param external_key: The external_key of this Account.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def email(self):
        """Gets the email of this Account.  # noqa: E501


        :return: The email of this Account.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Account.


        :param email: The email of this Account.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def bill_cycle_day_local(self):
        """Gets the bill_cycle_day_local of this Account.  # noqa: E501


        :return: The bill_cycle_day_local of this Account.  # noqa: E501
        :rtype: int
        """
        return self._bill_cycle_day_local

    @bill_cycle_day_local.setter
    def bill_cycle_day_local(self, bill_cycle_day_local):
        """Sets the bill_cycle_day_local of this Account.


        :param bill_cycle_day_local: The bill_cycle_day_local of this Account.  # noqa: E501
        :type: int
        """

        self._bill_cycle_day_local = bill_cycle_day_local

    @property
    def currency(self):
        """Gets the currency of this Account.  # noqa: E501


        :return: The currency of this Account.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Account.


        :param currency: The currency of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def parent_account_id(self):
        """Gets the parent_account_id of this Account.  # noqa: E501


        :return: The parent_account_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._parent_account_id

    @parent_account_id.setter
    def parent_account_id(self, parent_account_id):
        """Sets the parent_account_id of this Account.


        :param parent_account_id: The parent_account_id of this Account.  # noqa: E501
        :type: str
        """

        self._parent_account_id = parent_account_id

    @property
    def is_payment_delegated_to_parent(self):
        """Gets the is_payment_delegated_to_parent of this Account.  # noqa: E501


        :return: The is_payment_delegated_to_parent of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._is_payment_delegated_to_parent

    @is_payment_delegated_to_parent.setter
    def is_payment_delegated_to_parent(self, is_payment_delegated_to_parent):
        """Sets the is_payment_delegated_to_parent of this Account.


        :param is_payment_delegated_to_parent: The is_payment_delegated_to_parent of this Account.  # noqa: E501
        :type: bool
        """

        self._is_payment_delegated_to_parent = is_payment_delegated_to_parent

    @property
    def payment_method_id(self):
        """Gets the payment_method_id of this Account.  # noqa: E501


        :return: The payment_method_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, payment_method_id):
        """Sets the payment_method_id of this Account.


        :param payment_method_id: The payment_method_id of this Account.  # noqa: E501
        :type: str
        """

        self._payment_method_id = payment_method_id

    @property
    def reference_time(self):
        """Gets the reference_time of this Account.  # noqa: E501


        :return: The reference_time of this Account.  # noqa: E501
        :rtype: datetime
        """
        return self._reference_time

    @reference_time.setter
    def reference_time(self, reference_time):
        """Sets the reference_time of this Account.


        :param reference_time: The reference_time of this Account.  # noqa: E501
        :type: datetime
        """

        self._reference_time = reference_time

    @property
    def time_zone(self):
        """Gets the time_zone of this Account.  # noqa: E501


        :return: The time_zone of this Account.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Account.


        :param time_zone: The time_zone of this Account.  # noqa: E501
        :type: str
        """

        self._time_zone = time_zone

    @property
    def address1(self):
        """Gets the address1 of this Account.  # noqa: E501


        :return: The address1 of this Account.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this Account.


        :param address1: The address1 of this Account.  # noqa: E501
        :type: str
        """

        self._address1 = address1

    @property
    def address2(self):
        """Gets the address2 of this Account.  # noqa: E501


        :return: The address2 of this Account.  # noqa: E501
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """Sets the address2 of this Account.


        :param address2: The address2 of this Account.  # noqa: E501
        :type: str
        """

        self._address2 = address2

    @property
    def postal_code(self):
        """Gets the postal_code of this Account.  # noqa: E501


        :return: The postal_code of this Account.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this Account.


        :param postal_code: The postal_code of this Account.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def company(self):
        """Gets the company of this Account.  # noqa: E501


        :return: The company of this Account.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this Account.


        :param company: The company of this Account.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def city(self):
        """Gets the city of this Account.  # noqa: E501


        :return: The city of this Account.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Account.


        :param city: The city of this Account.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this Account.  # noqa: E501


        :return: The state of this Account.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Account.


        :param state: The state of this Account.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this Account.  # noqa: E501


        :return: The country of this Account.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Account.


        :param country: The country of this Account.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def locale(self):
        """Gets the locale of this Account.  # noqa: E501


        :return: The locale of this Account.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this Account.


        :param locale: The locale of this Account.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def phone(self):
        """Gets the phone of this Account.  # noqa: E501


        :return: The phone of this Account.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Account.


        :param phone: The phone of this Account.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def notes(self):
        """Gets the notes of this Account.  # noqa: E501


        :return: The notes of this Account.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this Account.


        :param notes: The notes of this Account.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def is_migrated(self):
        """Gets the is_migrated of this Account.  # noqa: E501


        :return: The is_migrated of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._is_migrated

    @is_migrated.setter
    def is_migrated(self, is_migrated):
        """Sets the is_migrated of this Account.


        :param is_migrated: The is_migrated of this Account.  # noqa: E501
        :type: bool
        """

        self._is_migrated = is_migrated

    @property
    def account_balance(self):
        """Gets the account_balance of this Account.  # noqa: E501


        :return: The account_balance of this Account.  # noqa: E501
        :rtype: float
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """Sets the account_balance of this Account.


        :param account_balance: The account_balance of this Account.  # noqa: E501
        :type: float
        """

        self._account_balance = account_balance

    @property
    def account_cba(self):
        """Gets the account_cba of this Account.  # noqa: E501


        :return: The account_cba of this Account.  # noqa: E501
        :rtype: float
        """
        return self._account_cba

    @account_cba.setter
    def account_cba(self, account_cba):
        """Sets the account_cba of this Account.


        :param account_cba: The account_cba of this Account.  # noqa: E501
        :type: float
        """

        self._account_cba = account_cba

    @property
    def audit_logs(self):
        """Gets the audit_logs of this Account.  # noqa: E501


        :return: The audit_logs of this Account.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this Account.


        :param audit_logs: The audit_logs of this Account.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockingState(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'blocked_id': 'str',
        'state_name': 'str',
        'service': 'str',
        'is_block_change': 'bool',
        'is_block_entitlement': 'bool',
        'is_block_billing': 'bool',
        'effective_date': 'datetime',
        'type': 'str',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'blocked_id': 'blockedId',
        'state_name': 'stateName',
        'service': 'service',
        'is_block_change': 'isBlockChange',
        'is_block_entitlement': 'isBlockEntitlement',
        'is_block_billing': 'isBlockBilling',
        'effective_date': 'effectiveDate',
        'type': 'type',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, blocked_id=None, state_name=None, service=None, is_block_change=None, is_block_entitlement=None, is_block_billing=None, effective_date=None, type=None, audit_logs=None):  # noqa: E501
        """BlockingState - a model defined in Swagger"""  # noqa: E501
        self._blocked_id = None
        self._state_name = None
        self._service = None
        self._is_block_change = None
        self._is_block_entitlement = None
        self._is_block_billing = None
        self._effective_date = None
        self._type = None
        self._audit_logs = None
        self.discriminator = None
        if blocked_id is not None:
            self.blocked_id = blocked_id
        if state_name is not None:
            self.state_name = state_name
        if service is not None:
            self.service = service
        if is_block_change is not None:
            self.is_block_change = is_block_change
        if is_block_entitlement is not None:
            self.is_block_entitlement = is_block_entitlement
        if is_block_billing is not None:
            self.is_block_billing = is_block_billing
        if effective_date is not None:
            self.effective_date = effective_date
        if type is not None:
            self.type = type
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def blocked_id(self):
        """Gets the blocked_id of this BlockingState.  # noqa: E501


        :return: The blocked_id of this BlockingState.  # noqa: E501
        :rtype: str
        """
        return self._blocked_id

    @blocked_id.setter
    def blocked_id(self, blocked_id):
        """Sets the blocked_id of this BlockingState.


        :param blocked_id: The blocked_id of this BlockingState.  # noqa: E501
        :type: str
        """

        self._blocked_id = blocked_id

    @property
    def state_name(self):
        """Gets the state_name of this BlockingState.  # noqa: E501


        :return: The state_name of this BlockingState.  # noqa: E501
        :rtype: str
        """
        return self._state_name

    @state_name.setter
    def state_name(self, state_name):
        """Sets the state_name of this BlockingState.


        :param state_name: The state_name of this BlockingState.  # noqa: E501
        :type: str
        """

        self._state_name = state_name

    @property
    def service(self):
        """Gets the service of this BlockingState.  # noqa: E501


        :return: The service of this BlockingState.  # noqa: E501
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this BlockingState.


        :param service: The service of this BlockingState.  # noqa: E501
        :type: str
        """

        self._service = service

    @property
    def is_block_change(self):
        """Gets the is_block_change of this BlockingState.  # noqa: E501


        :return: The is_block_change of this BlockingState.  # noqa: E501
        :rtype: bool
        """
        return self._is_block_change

    @is_block_change.setter
    def is_block_change(self, is_block_change):
        """Sets the is_block_change of this BlockingState.


        :param is_block_change: The is_block_change of this BlockingState.  # noqa: E501
        :type: bool
        """

        self._is_block_change = is_block_change

    @property
    def is_block_entitlement(self):
        """Gets the is_block_entitlement of this BlockingState.  # noqa: E501


        :return: The is_block_entitlement of this BlockingState.  # noqa: E501
        :rtype: bool
        """
        return self._is_block_entitlement

    @is_block_entitlement.setter
    def is_block_entitlement(self, is_block_entitlement):
        """Sets the is_block_entitlement of this BlockingState.


        :param is_block_entitlement: The is_block_entitlement of this BlockingState.  # noqa: E501
        :type: bool
        """

        self._is_block_entitlement = is_block_entitlement

    @property
    def is_block_billing(self):
        """Gets the is_block_billing of this BlockingState.  # noqa: E501


        :return: The is_block_billing of this BlockingState.  # noqa: E501
        :rtype: bool
        """
        return self._is_block_billing

    @is_block_billing.setter
    def is_block_billing(self, is_block_billing):
        """Sets the is_block_billing of this BlockingState.


        :param is_block_billing: The is_block_billing of this BlockingState.  # noqa: E501
        :type: bool
        """

        self._is_block_billing = is_block_billing

    @property
    def effective_date(self):
        """Gets the effective_date of this BlockingState.  # noqa: E501


        :return: The effective_date of this BlockingState.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this BlockingState.


        :param effective_date: The effective_date of this BlockingState.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    @property
    def type(self):
        """Gets the type of this BlockingState.  # noqa: E501


        :return: The type of this BlockingState.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BlockingState.


        :param type: The type of this BlockingState.  # noqa: E501
        :type: str
        """
        allowed_values = ["SUBSCRIPTION", "SUBSCRIPTION_BUNDLE", "ACCOUNT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def audit_logs(self):
        """Gets the audit_logs of this BlockingState.  # noqa: E501


        :return: The audit_logs of this BlockingState.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this BlockingState.


        :param audit_logs: The audit_logs of this BlockingState.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockingState, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockingState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Price(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'str',
        'value': 'float'
    }

    attribute_map = {
        'currency': 'currency',
        'value': 'value'
    }

    def __init__(self, currency=None, value=None):  # noqa: E501
        """Price - a model defined in Swagger"""  # noqa: E501
        self._currency = None
        self._value = None
        self.discriminator = None
        if currency is not None:
            self.currency = currency
        if value is not None:
            self.value = value

    @property
    def currency(self):
        """Gets the currency of this Price.  # noqa: E501


        :return: The currency of this Price.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Price.


        :param currency: The currency of this Price.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def value(self):
        """Gets the value of this Price.  # noqa: E501


        :return: The value of this Price.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Price.


        :param value: The value of this Price.  # noqa: E501
        :type: float
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Price, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Price):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
